==> jetm-jee-1.3.0-20130416.001039-5-sources.jar: etm/contrib/integration/jee/jsf/NameInterceptingActionListener.java <==
/*
 *
 * Copyright (c) void.fm
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name void.fm nor the names of its contributors may be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

package etm.contrib.integration.jee.jsf;

import etm.core.monitor.EtmPoint;

import javax.el.MethodExpression;
import javax.faces.component.ActionSource;
import javax.faces.component.ActionSource2;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.el.MethodBinding;
import javax.faces.event.AbortProcessingException;
import javax.faces.event.ActionEvent;
import javax.faces.event.ActionListener;

/**
 * Renames request parent etm point to current executed action
 * and delegates action event to delegate.
 *
 * @author void.fm
 * @version $Revision: 372 $
 */
public class NameInterceptingActionListener implements ActionListener {

  private ActionListener delegate;

  public NameInterceptingActionListener(ActionListener aDelegate) {
    delegate = aDelegate;
  }

  public void processAction(ActionEvent actionEvent) throws AbortProcessingException {
    UIComponent component = actionEvent.getComponent();
    EtmPoint etmRootPoint =
      (EtmPoint) FacesContext.getCurrentInstance().getAttributes().get(JsfPerformancePhaseListener.ROOT_ETM_POINT);
    if (etmRootPoint != null) {
      MethodExpression methodExpression = null;
      if (component instanceof ActionSource2) {
        methodExpression = ((ActionSource2) component).getActionExpression();
        if (methodExpression != null) {
          etmRootPoint.alterName("JSF Action " + methodExpression.getExpressionString());
        }
      }
      if (methodExpression == null && component instanceof ActionSource) {
        MethodBinding methodBinding = ((ActionSource) component).getAction();
        if (methodBinding != null) {
          etmRootPoint.alterName("JSF Action " + methodBinding.getExpressionString());
        }
      }
    }

    delegate.processAction(actionEvent);
  }
}

==> jetm-jee-1.3.0-20130419.122304-10-sources.jar: etm/contrib/integration/jee/jsf/NameInterceptingActionListener.java <==
/*
 *
 * Copyright (c) void.fm
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name void.fm nor the names of its contributors may be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

package etm.contrib.integration.jee.jsf;

import etm.core.monitor.EtmPoint;

import javax.el.MethodExpression;
import javax.faces.component.ActionSource;
import javax.faces.component.ActionSource2;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.el.MethodBinding;
import javax.faces.event.AbortProcessingException;
import javax.faces.event.ActionEvent;
import javax.faces.event.ActionListener;

/**
 * Renames request parent etm point to current executed action
 * and delegates action event to delegate.
 *
 * @author void.fm
 * @version $Revision: 372 $
 */
public class NameInterceptingActionListener implements ActionListener {

  private ActionListener delegate;

  public NameInterceptingActionListener(ActionListener aDelegate) {
    delegate = aDelegate;
  }

  public void processAction(ActionEvent actionEvent) throws AbortProcessingException {
    UIComponent component = actionEvent.getComponent();
    EtmPoint etmRootPoint =
      (EtmPoint) FacesContext.getCurrentInstance().getAttributes().get(EtmJsfPlugin.ROOT_ETM_POINT);
    if (etmRootPoint != null) {
      MethodExpression methodExpression = null;
      if (component instanceof ActionSource2) {
        methodExpression = ((ActionSource2) component).getActionExpression();
        if (methodExpression != null) {
          etmRootPoint.alterName("JSF Action " + methodExpression.getExpressionString());
        }
      }
      if (methodExpression == null && component instanceof ActionSource) {
        MethodBinding methodBinding = ((ActionSource) component).getAction();
        if (methodBinding != null) {
          etmRootPoint.alterName("JSF Action " + methodBinding.getExpressionString());
        }
      }
    }

    delegate.processAction(actionEvent);
  }
}
